
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from django.db import models
from django.conf import settings


class AdminManager(models.Manager):
    """Manager for Admin model."""
    def get_by_login_and_password(self, aname, passwd):
        """Check if admin with given login and password exists."""
        try:
            return self.get(aname=aname, passwd=passwd)
        except Admin.DoesNotExist:
            return None

    def get_list(self, is_general_admin, current_admin_pk):
        """
        Return list of all admin records for general admin
        or list with just self record for custom admin.
        """
        query_set = super(AdminManager, self).get_query_set()
        if not is_general_admin:
            query_set = query_set.filter(pk=current_admin_pk)

        return query_set.order_by('aname').all()


class Admin(models.Model):
    """System Administrator model."""
    admid = models.AutoField(primary_key=True)
    aname = models.CharField(unique=True, max_length=255)
    passwd = models.CharField(max_length=255)
    type = models.CharField(
        max_length=1,
        choices=settings.ROLE_TYPES,
        default=settings.ROLE_CUSTOM
    )

    objects = AdminManager()

    class Meta:
        db_table = u'admins'

    def __unicode__(self):
        return self.aname
