
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

import httplib

from django.test import TestCase
from django.core.urlresolvers import reverse
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from admins.models import Admin
from admins.forms import LoginForm


class NoAuthAdminViewTestCase(TestCase):
    def test_login(self):
        response = self.client.get(reverse('auth.views.login'))

        self.assertEqual(response.status_code, httplib.OK)
        self.assertTemplateUsed(response, 'auth/login.html')

        self.assertEqual(
            type(response.context['form']), LoginForm
        )

    def test_login_send_empty_data(self):
        data = {
            'aname': '',
            'passwd': ''
        }

        response = self.client.post(reverse('auth.views.login'), data)

        self.assertEqual(response.status_code, httplib.OK)
        self.assertTemplateUsed(response, 'auth/login.html')

        self.assertFormError(
            response,
            'form',
            'aname',
            _(u'This field is required.')
        )
        self.assertFormError(
            response,
            'form',
            'passwd',
            _(u'This field is required.')
        )

    def test_login_send_invalid_data(self):
        aname = 'test_name'
        passwd = 'test_password'

        admin = Admin()
        admin.aname = aname + '_error'
        admin.passwd = passwd
        admin.save()

        data = {
            'aname': aname,
            'passwd': passwd
        }

        response = self.client.post(reverse('auth.views.login'), data)

        self.assertEqual(response.status_code, httplib.OK)
        self.assertTemplateUsed(response, 'auth/login.html')

        self.assertFormError(
            response, 'form', None, _(u'Login incorrect.')
        )

    def test_login_send_valid_data(self):
        aname = 'test_name'
        passwd = 'test_password'

        admin = Admin()
        admin.aname = aname
        admin.passwd = passwd
        admin.save()

        data = {
            'aname': aname,
            'passwd': passwd
        }

        response = self.client.post(settings.LOGIN_URL, data)
        self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)

    def test_logout(self):
        response = self.client.get(settings.LOGOUT_URL)

        self.assertRedirects(response, settings.LOGIN_URL)
