
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from django import forms
from django.conf import settings
from django.utils.translation import ugettext as _


GUID_PATTERN = r'-'.join([
    r'^[0-9a-fA-F]{8}',
    r'[0-9a-fA-F]{4}',
    r'[0-9a-fA-F]{4}',
    r'[0-9a-fA-F]{4}',
    r'[0-9a-fA-F]{12}$'
])


class CreateInstallationForm(forms.Form):
    owner_id = forms.RegexField(
        required=True,
        regex=GUID_PATTERN
    )

    product_id = forms.RegexField(
        required=True,
        regex=GUID_PATTERN, 
        widget=forms.HiddenInput()
    )

    product_version = forms.IntegerField(
        required=True,
        min_value=0, 
        widget=forms.HiddenInput()
    )


class ActivateLicenseForm(forms.Form):
    card_number = forms.IntegerField(
        required=True,
        min_value=0
    )

    card_pin = forms.RegexField(
        required=True,
        regex=r'^[a-z0-9A-Z]+$'
    )

    license_type = forms.ChoiceField(
        required=True,
        choices=[
            (settings.LICENSE_TYPE, _('Card'))
        ]
    )
