
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from django.db import models

from roles.models import Category


class Domain(models.Model):
    """Domain model."""
    did = models.AutoField(primary_key=True)
    dname = models.CharField(
        null=False,
        blank=False,
        unique=True,
        max_length=255
    )
    categories = models.ManyToManyField(
        Category,
        through='DomainCategory'
    )

    class Meta:
        db_table = u'domains'

    def __unicode__(self):
        return self.dname


class DomainCategoryManager(models.Manager):
    """Manager for DomainCategory model."""
    def create_or_delete(self, cat_checked, domain, cat_id):
        cat = Category.objects.get(cat=cat_id)

        if cat_checked:
            dc = DomainCategory()

            dc.domain = domain
            dc.cat = cat

            dc.save()
        else:
            try:
                dc = DomainCategory.objects.get(
                    domain=domain,
                    cat=cat
                )
                dc.delete()
            except DomainCategory.DoesNotExist:
                pass

    def get_by_domain(self, domain):
        return self.select_related().filter(domain=domain)


class DomainCategory(models.Model):
    domain = models.ForeignKey(Domain, db_column=u'did')
    cat = models.ForeignKey(Category, db_column=u'cat')

    objects = DomainCategoryManager()

    class Meta:
        db_table = u'domains_categories'
