
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from __future__ import with_statement
import os

from django.db import DatabaseError
from django.core.management.base import BaseCommand
from django.conf import settings

from statistics.models import StatisticsItem, MODES
from statistics.lib import CustomLogProvider


class Command(BaseCommand):
    help = u'Copy statistics from txt log file to database.'

    def handle(self, *args, **options):
        position_filename = settings.STATISTICS_LOG_POSITION_FILE

        try:
            with open(position_filename) as fp:
                start_position = int(fp.readline())
        except (IOError, OSError, ValueError):
            start_position = 0

        provider = CustomLogProvider(
            settings.STATISTICS_LOG_PATH,
            start_position=start_position,
            debug=False
        )

        new_position = 0
        for data in provider:
            try:
                item = StatisticsItem(
                    date=data['date'],
                    action=data['action'],
                    url=data['url'],
                    client_ip=data['client_ip'],
                    user=data['user'],
                    role=data['role'],
                    mod=MODES[data['mod']],
                    categories=data['categories']
                )
                item.save()

                new_position = provider.tell()
            except DatabaseError:
                continue

        try:
            with open(position_filename, 'w') as fp:
                fp.write(str(new_position))
        except (IOError, OSError):
            pass
