
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

import csv
import logging

from django.conf import settings

from utils.decorators import log_call, reraise


class UserStorageException(Exception):
    """Base user storage exception."""
    def __init__(self, code=0, message=''):
        Exception.__init__(self, code, message)

        self._code = code
        self._message = unicode(message)

    @property
    def code(self):
        return self._code

    @property
    def message(self):
        return self._message


logger = logging.getLogger('userstorage')


class FileUserStorage(object):
    """File-based user storage class."""
    fieldnames = ('login', 'password')

    def __init__(self, path, delimiter=':'):
        self.path = path
        self.delimiter = delimiter

    @reraise((csv.Error, IOError, OSError), UserStorageException)
    @log_call(logger)
    def all(self):
        reader = csv.DictReader(
            open(self.path, 'r'),
            fieldnames=self.fieldnames,
            delimiter=self.delimiter
        )

        result = []
        for row in reader:
            result.append(row)

        return result


storage = FileUserStorage(settings.USERS_FILE_PATH)
