
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from django.db import models
from ipaddr import IPAddress, IPNetwork

from roles.models import Role


class UserManager(models.Manager):
    """Manager for User model."""
    def user_count_with_role(self, role):
        """Return count of all users with a given role."""
        return self.filter(rolid=role).count()

    def get_all_join_roles(self):
        """Return list of all users and their roles."""
        return self.select_related(
            'rolid'
        ).order_by('uname', 'addr').all()

    def get_by_params(self, uname, addr, mask):
        """Return user by given params."""
        try:
            return self.filter(
                uname=uname, addr=addr, mask=mask
            ).get()
        except (User.DoesNotExist):
            return None

    def is_default_user(self, instance):
        if not instance:
            return False

        return instance.is_default()


class User(models.Model):
    """User model."""
    useid = models.AutoField(primary_key=True)
    uname = models.CharField(max_length=40)
    addr = models.IntegerField(default=0)
    mask = models.IntegerField(default=0)
    rolid = models.ForeignKey(
        Role,
        db_column=u'rolid',
        null=False,
        blank=False
    )

    objects = UserManager()

    class Meta:
        db_table = u'users'

    def __unicode__(self):
        return self.uname if not self.is_default() else u'*'

    def get_addr_str(self):
        return str(IPAddress(self.addr))

    def get_mask_str(self):
        return str(IPAddress(self.mask))

    def is_default(self):
        if not self.pk:
            return False

        return (
            (not self.uname) and (not self.addr) and (not self.mask)
        )
