
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

import os
import shutil

from django.test import TestCase
from django.utils.importlib import import_module
from django.conf import settings

from admins.models import Admin


class BaseViewTestCase(TestCase):
    admin_pk = 1

    admin_login = 'test_admin'

    admin_password = 'test_password'

    def setUp(self):
        admin = Admin()

        admin.pk = self.admin_pk
        admin.aname = self.admin_login
        admin.passwd = self.admin_password

        admin.save()

        apps = list(settings.INSTALLED_APPS)
        apps.insert(0, 'django.contrib.sessions')
        settings.INSTALLED_APPS = tuple(apps)

        if settings.SESSION_ENGINE == \
            'django.contrib.sessions.backends.file':
            self.old_session_file_path = settings.SESSION_FILE_PATH

            settings.SESSION_FILE_PATH = os.path.join(
                self.old_session_file_path, 'test'
            )

            if not os.path.exists(settings.SESSION_FILE_PATH):
                os.mkdir(settings.SESSION_FILE_PATH)

        engine = import_module(settings.SESSION_ENGINE)
        store = engine.SessionStore()
        # we need to make load() work, or the cookie is worthless.
        store.save()

        self.client.cookies[settings.SESSION_COOKIE_NAME] = store.session_key

        session = self.client.session
        session['current_admin'] = admin
        session.save()

    def tearDown(self):
        admin = self.get_current_admin()
        if admin:
            admin.delete()

        session = self.client.session
        session.flush()

        apps = list(settings.INSTALLED_APPS)
        apps.remove('django.contrib.sessions')
        settings.INSTALLED_APPS = tuple(apps)

        if settings.SESSION_ENGINE == \
            'django.contrib.sessions.backends.file':
            shutil.rmtree(settings.SESSION_FILE_PATH)

            settings.SESSION_FILE_PATH = self.old_session_file_path

    def get_current_admin(self):
        try:
            return Admin.objects.get(pk=self.admin_pk)
        except Admin.DoesNotExist:
            return None

    def switch_current_admin_role(self, role_type):
        admin = self.get_current_admin()
        if admin:
            admin.type = role_type
            admin.save()

            session = self.client.session
            session['current_admin'] = admin
            session.save()
