
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from django import forms
from django.utils.translation import ugettext_lazy as _

from admins.models import Admin


class AddAdminForm(forms.ModelForm):
    """Form for adding new adminstrator."""
    aname = forms.RegexField(
        label=_(u'User name'),
        max_length=30,
        regex=r'^[\w.@+-]+$'
    )

    password1 = forms.CharField(
        label=_(u'Password'),
        widget=forms.PasswordInput
    )

    password2 = forms.CharField(
        label=_(u'Password confirmation'),
        widget=forms.PasswordInput
    )

    class Meta:
        model = Admin
        fields = ('aname',)

    def clean_password2(self):
        password1 = self.cleaned_data.get('password1', '')
        password2 = self.cleaned_data['password2']
        if password1 != password2:
            raise forms.ValidationError(
                _(u"The two password fields didn't match.")
            )

        return password2

    def save(self, commit=True):
        admin = super(AddAdminForm, self).save(commit=False)
        admin.passwd = self.cleaned_data['password1']
        if commit:
            admin.save()

        return admin


class LoginForm(forms.ModelForm):
    """Auth form."""
    aname = forms.CharField(
        label=_(u'User name'),
    )

    passwd = forms.CharField(
        label=_(u'Password'),
        widget=forms.PasswordInput
    )

    class Meta:
        model = Admin
        fields = ('aname', 'passwd')

    def clean(self):
        aname = self.cleaned_data.get('aname')
        passwd = self.cleaned_data.get('passwd')

        admin = Admin.objects.get_by_login_and_password(aname, passwd)

        if not admin:
            raise forms.ValidationError(_(u'Login incorrect.'))
        else:
            self.instance = admin

        return self.cleaned_data


class AdminPasswordChangeForm(forms.Form):
    """A form used to change the password."""
    password1 = forms.CharField(
        label=_(u'Password'),
        widget=forms.PasswordInput
    )
    password2 = forms.CharField(
        label=_(u'Password (again)'),
        widget=forms.PasswordInput
    )

    def __init__(self, admin, *args, **kwargs):
        self.admin = admin
        super(AdminPasswordChangeForm, self).__init__(*args, **kwargs)

    def clean_password2(self):
        password1 = self.cleaned_data.get('password1', '')
        password2 = self.cleaned_data['password2']

        if password1 and password2:
            if password1 != password2:
                raise forms.ValidationError(
                    _(u"The two password fields didn't match.")
                )

        return password2

    def save(self, commit=True):
        """Save the new password."""
        self.admin.passwd = self.cleaned_data.get('password1')
        if commit:
            self.admin.save()

        return self.admin
