
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

import httplib

from django.core.urlresolvers import reverse
from django.test import TestCase
from django.conf import settings

from utils.test import BaseViewTestCase
from license.forms import CreateInstallationForm, ActivateLicenseForm


class NoAuthLicenseViewTestCase(TestCase):
    def test_main(self):
        response = self.client.get(reverse('license.views.main'))

        self.assertRedirects(response, settings.LOGIN_URL)

    def test_create_installation(self):
        response = self.client.get(
            reverse('license.views.create_installation')
        )

        self.assertRedirects(response, settings.LOGIN_URL)

    def test_activate_license(self):
        response = self.client.get(
            reverse('license.views.activate_license')
        )

        self.assertRedirects(response, settings.LOGIN_URL)


class LicenseViewTestCase(BaseViewTestCase):
    def test_main(self):
        response = self.client.get(reverse('license.views.main'))

        self.assertEqual(response.status_code, httplib.OK)
        #self.assertTemplateUsed(response, 'license/main.html')

    def test_create_installation(self):
        settings.LICENSE_INSTALLATION_ID.filepath = '/dev/null'

        response = self.client.get(
            reverse('license.views.create_installation')
        )

        self.assertEqual(response.status_code, httplib.OK)
        self.assertTemplateUsed(response, 'license/installation_form.html')

        self.assertEqual(
            type(response.context['form']), CreateInstallationForm
        )

    def test_activate_license(self):
        settings.LICENSE_ID.filepath = '/dev/null'

        response = self.client.get(
            reverse('license.views.activate_license')
        )

        self.assertEqual(response.status_code, httplib.OK)
        self.assertTemplateUsed(response, 'license/activation_form.html')

        self.assertEqual(
            type(response.context['form']), ActivateLicenseForm
        )
