
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from django import forms
from django.utils.translation import ugettext as _
from django.conf import settings

from core.widgets import HiddenBooleanInput
from models import Role


class RoleForm(forms.ModelForm):
    """Form for adding new role."""
    rname = forms.RegexField(
        required=True,
        regex=r'^[\w\.]+$',
        label=_(u'Role name')
    )

    class Meta:
        model = Role
        fields = ('rname',)


class AddListItemForm(forms.Form):
    """Form for lists."""
    rolid = forms.IntegerField(widget=forms.HiddenInput())
    action = forms.CharField(widget=forms.HiddenInput())
    url = forms.RegexField(
        required=True,
        regex=r'^\w+://([^/]+\.)?\S+\.\S+($|/)'
    )
    exact_match = forms.BooleanField(
        required=False,
        label=_(u'Exact match')
    )


class ParentRolesForm(forms.Form):
    """Parent roles form."""
    def __init__(
        self, possible_parent_roles_list, admin_type, *args, **kwargs):
        super(ParentRolesForm, self).__init__(*args, **kwargs)

        # See ticket #11303.
        forms.BooleanField.hidden_widget = HiddenBooleanInput

        for role in possible_parent_roles_list:
            self.fields['role_%d' % role.pk] = forms.BooleanField(
                show_hidden_initial=True, required=False, label=role.rname
            )

        self.admin_type = admin_type

    def clean(self):
        if self.admin_type == settings.ROLE_CUSTOM:
            checked_category_count = 0
            for key, value in self.cleaned_data.items():
                if key.startswith('role') and value:
                    checked_category_count += 1

            if not checked_category_count:
                raise forms.ValidationError(
                    _(u'At least one parent role should be chosen.')
                )

        return self.cleaned_data


class CategoryListForm(forms.Form):
    """Category list form."""
    def __init__(self, category_list, *args, **kwargs):
        super(CategoryListForm, self).__init__(*args, **kwargs)

        # See ticket #11303.
        forms.BooleanField.hidden_widget = HiddenBooleanInput

        for item in category_list:
            self.fields['category_%d' % item.cat] = forms.BooleanField(
                show_hidden_initial=True, required=False, label=item.cname
            )
