
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#


class StatisticsRouter(object):
    """A router to control all database operations on models in
    the statistics application"""

    def db_for_read(self, model, **hints):
        """
        Point all operations on statistics models
        to 'statistics' connection
        """
        if model._meta.app_label == 'statistics':
            return 'statistics'

        return None

    def db_for_write(self, model, **hints):
        """
        Point all operations on statistics models
        to 'statistics' connection
        """
        if model._meta.app_label == 'statistics':
            return 'statistics'

        return None

    def allow_relation(self, obj1, obj2, **hints):
        """
        Allow any relation if a model in statistics is involved
        """
        if (obj1._meta.app_label == 'statistics' or
            obj2._meta.app_label == 'statistics'):
            return True

        return None

    def allow_syncdb(self, db, model):
        """
        Make sure the statistics app
        only appears on the 'statistics' connection
        """
        if db == 'statistics':
            return model._meta.app_label == 'statistics'
        elif model._meta.app_label == 'statistics':
            return False

        return None
