
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

import httplib
import random
from datetime import datetime

from django.test import TestCase
from django.conf import settings

from utils.test import BaseViewTestCase
from statistics.models import StatisticsItem, MODES
from statistics.forms import FilterForm, CHART_FORMAT


class NoAuthStatisticsViewTestCase(TestCase):
    def test_main(self):
        response = self.client.get('/statistics/')

        self.assertRedirects(response, settings.LOGIN_URL)

    def test_chart_data(self):
        response = self.client.get('/statistics/chartdata/')

        self.assertRedirects(response, settings.LOGIN_URL)


class StatisticsViewTestCase(BaseViewTestCase):
    def test_main(self):
        response = self.client.get('/statistics/')

        self.assertEqual(response.status_code, httplib.OK)
        self.assertTemplateUsed(response, 'statistics/main.html')
        self.assertEqual(type(response.context['form']), FilterForm)

    def test_empty_chart_data(self):
        response = self.client.get('/statistics/chartdata/')

        self.assertEqual(response.status_code, httplib.NOT_FOUND)

    def test_chart_data(self):
        actions = (
            settings.ACTION_ACCEPT,
            settings.ACTION_REJECT,
            settings.ACTION_REDIRECT
        )

        for i in xrange(10):
            item = StatisticsItem(
                date=datetime.now(),
                action=random.choice(actions),
                mod=random.choice(MODES.values())
            )
            item.save()

        data = {
            'format': CHART_FORMAT,
            'from_date_day': '1',
            'from_date_month': '1',
            'from_date_year': '1970',
            'to_date_day': '18',
            'to_date_month': '1',
            'to_date_year': '2038',
            'items_per_page': 100
        }

        response = self.client.post('/statistics/', data)

        self.assertEqual(response.status_code, httplib.OK)
        self.assertTemplateUsed(response, 'statistics/main.html')
        self.assertEqual(type(response.context['form']), FilterForm)

        response = self.client.get('/statistics/chartdata/')

        self.assertEqual(response.status_code, httplib.OK)
        self.assertEqual(response['Content-Type'], 'application/json')
