
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

# Django settings for webadmin project.

from __future__ import with_statement
import sys
import os

from django.core.exceptions import ImproperlyConfigured
from django.utils.translation import ugettext_lazy as _

from utils import get_exist_path, get_config_options


PROJECT_ROOT = os.path.dirname(os.path.abspath(__file__))
PROJECT_NAME = os.path.split(PROJECT_ROOT)[-1]


apps_path = os.path.join(PROJECT_ROOT, 'apps')


for path in [PROJECT_ROOT, apps_path]:
    if path not in sys.path:
        sys.path.append(path)

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'nh=xrps&39ln)erey6#0*o30***c+j9@88hz4@1z$r4lk!j_*s'

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
# If running in a Windows environment this must be set to the same as your
# system time zone.

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale
USE_L10N = True

TIME_ZONE = 'Europe/Moscow'

LANGUAGES = (
  ('ru', 'Russian')
)

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'ru'

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = ''

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = ''

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = ''

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# URL prefix for admin static files -- CSS, JavaScript and images.
# Make sure to use a trailing slash.
# Examples: "http://foo.com/static/admin/", "/static/admin/".
ADMIN_MEDIA_PREFIX = '/static/admin/'

# Additional locations of static files
STATICFILES_DIRS = (
    os.path.join(PROJECT_ROOT, 'static'),
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
#    'django.contrib.staticfiles.finders.DefaultStorageFinder',
)

# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
#     'django.template.loaders.eggs.Loader',
)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.core.context_processors.request',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.static',
    'django.contrib.messages.context_processors.messages',

    'core.context_processors.base_constants',
    'core.context_processors.config_options'
)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.middleware.transaction.TransactionMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',

    'core.middleware.ForbiddenFallbackMiddleware',
)

ROOT_URLCONF = 'webadmin.urls'

TEMPLATE_DIRS = (
    os.path.join(PROJECT_ROOT, 'templates'),
)

INSTALLED_APPS = (
    'django.contrib.staticfiles',
    'django.contrib.messages',

    'core',
    'main',
    'users',
    'roles',
    'manual_categorization',
    'categories',
    'admins',
    'auth',
    'statistics',
    'license',
)

SESSION_ENGINE = 'django.contrib.sessions.backends.file'

SESSION_EXPIRE_AT_BROWSER_CLOSE = True

MESSAGE_STORAGE = 'django.contrib.messages.storage.cookie.CookieStorage'

ADMINS = (
    # ('Your Name', 'your_email@example.com'),
)

MANAGERS = ADMINS

#
# Custom
#

# root role
ROLE_GENERAL = 'g'

ROLE_CUSTOM = 'c'

ROLE_TYPES = (
    (ROLE_GENERAL, _('General')),
    (ROLE_CUSTOM, _('Custom'))
)

# accept request
ACTION_ACCEPT = 0

# reject request
ACTION_REJECT = 1

# redirect request to special page
ACTION_REDIRECT = 2

ACTION_TYPES = (
    (ACTION_ACCEPT, _('Accept')),
    (ACTION_REJECT, _('Reject')),
    (ACTION_REDIRECT, _('Redirect'))
)

CONFIG_FILENAME = 'webadmin.conf'

CONFIG_PATH_LIST = [
    './', 
    '/usr/local/etc/netpolice',
     '/etc/netpolice',
     '/usr/local/etc',
     '/etc',
]


full_config_filename = get_exist_path(
    CONFIG_FILENAME, CONFIG_PATH_LIST
)

if not full_config_filename:
    raise ImproperlyConfigured(
        'Configuration file %s not found.' % CONFIG_FILENAME
    )


class Config(object):
    """Config object."""
    def __init__(self, options):
        self._options = options

    def __getitem__(self, key):
        try:
            return self._options[key]
        except KeyError:
            raise ImproperlyConfigured(
                'Option "%s" must be defined in the configuration file.' %
                key
            )

    def get(self, key, otherwise=None):
        return self._options.get(key, otherwise)

    def copy(self):
        return self._options.copy()


try:
    options = Config(
        get_config_options(full_config_filename)
    )
except Exception, exc:
    raise ImproperlyConfigured(
        'Configuration file %s error: %s.' %
        (full_config_filename, exc)
    )

OPTIONS = options

DEBUG = bool(int(options.get('common_debug', False)))

TEMPLATE_DEBUG = DEBUG

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.%s' % options['db_engine'],
        'NAME': options['db_name'],
        'USER': options['db_user'],
        'PASSWORD': options['db_password'],
        'HOST': options['db_host'],
        'PORT': options['db_port']
    },
    'statistics': {
        'ENGINE': 'django.db.backends.%s' % options['statistics_db_engine'],
        'NAME': options['statistics_db_name'],
        'USER': options['statistics_db_user'],
        'PASSWORD': options['statistics_db_password'],
        'HOST': options['statistics_db_host'],
        'PORT': options['statistics_db_port']
    }
}

DATABASE_ROUTERS = ['statistics.router.StatisticsRouter']


CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',
        'LOCATION': [
            '%s:%s' % (options['cache_host'], options['cache_port'])
        ]
    }
}

SESSION_FILE_PATH = options['session_file_path']

if not os.path.exists(SESSION_FILE_PATH):
    try:
        os.mkdir(SESSION_FILE_PATH)
    except OSError, exc:
        raise ImproperlyConfigured(
            "Can't create session directory %s, error: %s." % (
                SESSION_FILE_PATH, exc
            )
        )

SESSION_COOKIE_NAME = 'webadmin'


# Statistics log variables.

STATISTICS_LOG_PATH = options['statistics_log_path']

STATISTICS_LOG_POSITION_FILE = options['statistics_log_position_file']

# License variables.

LICENSE_KEYS_PATH = options['license_keys_path']

LICENSE_SERVER_WSDL_URL = options['license_server_wsdl_url']

LICENSE_SERVER_TIMEOUT = int(options['license_server_timeout'])

LICENSE_TYPE = 'card'

class LazyFileProxy(object):
    def __init__(self, filepath):
        self.filepath = filepath

    def get(self, default=None):
        try:
            with (open(self.filepath)) as fp:
                return fp.readline().strip()
        except IOError:
            return default

    def set(self, value):
        with(open(self.filepath, 'w')) as fp:
            fp.write(value)


LICENSE_ENABLE = bool(int(options.get('license_enable', 0)))

LICENSE_OWNER_ID = LazyFileProxy(
    os.path.join(LICENSE_KEYS_PATH, 'owner_id')
)

LICENSE_PRODUCT_ID = LazyFileProxy(
    os.path.join(LICENSE_KEYS_PATH, 'product_id')
)
not LICENSE_PRODUCT_ID.get() and LICENSE_PRODUCT_ID.set(options.get('product_id','83e98483-b8fa-4514-a89f-48381331ce2d'))

LICENSE_PRODUCT_VERSION = LazyFileProxy(
    os.path.join(LICENSE_KEYS_PATH, 'product_version')
)
not LICENSE_PRODUCT_VERSION.get() and LICENSE_PRODUCT_VERSION.set(options.get('product_version','16842752'))

LICENSE_CARD_NUMBER = LazyFileProxy(
    os.path.join(LICENSE_KEYS_PATH, 'card_number')
)

LICENSE_CARD_PIN = LazyFileProxy(
    os.path.join(LICENSE_KEYS_PATH, 'card_pin')
)

LICENSE_INSTALLATION_ID = LazyFileProxy(
    os.path.join(LICENSE_KEYS_PATH, 'installation_id')
)

LICENSE_ID = LazyFileProxy(
    os.path.join(LICENSE_KEYS_PATH, 'license_id')
)


LIMITS_USER_COUNT = int(options.get('limits_user_count', 0))


USERS_FILE_PATH = options['users_file_path']


DNS_ZONE_PATH = options['dns_zone_path']

DNS_TTL = '3h'


LOGIN_URL = '/auth/login/'

LOGIN_REDIRECT_URL = '/'

LOGOUT_URL = '/auth/logout/'


if DEBUG:
    LOGGING = {
        'version': 1,
        'disable_existing_loggers': True,
        'formatters': {
            'base': {
                'format': '%(levelname)s %(asctime)s %(message)s'
            },
        },
        'handlers': {
            'null': {
                'level': 'DEBUG',
                'class': 'django.utils.log.NullHandler',
            },
            'console': {
                'level': 'DEBUG',
                'class': 'logging.StreamHandler',
                'formatter': 'base'
            }
        },
        'loggers': {
            'license.utils': {
                'handlers': ['console'],
                'level': 'DEBUG'
            },
            'userstorage': {
                'handlers': ['console'],
                'level': 'DEBUG'
            },
        }
    }

try:
    from settings_local import *

    INSTALLED_APPS = tuple(
        list(INSTALLED_APPS) + list(LOCAL_INSTALLED_APPS)
    )

    MIDDLEWARE_CLASSES = tuple(
        list(MIDDLEWARE_CLASSES) + list(LOCAL_MIDDLEWARE_CLASSES)
    )

except ImportError:
    pass
