
#
# Copyright (c) 2011, MegaVersiya, LTD. All rights reserved.
#
# Redistribution and use in source and binary forms, with or
# without modification, are permitted provided that
# the following conditions are met:
# Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
# Neither the name of the MegaVersiya, LTD nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT * LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from __future__ import with_statement
import os

from django.core.exceptions import ImproperlyConfigured


class Config(object):
    """Config object."""
    def __init__(self, options):
        self._options = options

    def __getitem__(self, key):
        try:
            return self._options[key]
        except KeyError:
            raise ImproperlyConfigured(
                'Option "%s" must be defined in the configuration file.' %
                key
            )

    def get(self, key, otherwise=None):
        return self._options.get(key, otherwise)

    def copy(self):
        return self._options.copy()


class LazyFileProxy(object):
    def __init__(self, filepath='/dev/null'):
        self.filepath = filepath

    def get(self, default=None):
        try:
            with (open(self.filepath)) as fp:
                return fp.readline().strip()
        except IOError:
            return default

    def set(self, value):
        with(open(self.filepath, 'w')) as fp:
            fp.write('%s' % value)

    def delete(self):
        try:
            os.unlink(self.filepath)

            return True
        except OSError:
            return False
